package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.KunpengDesktopCloudHosts;

/**
 * 鲲鹏桌面云主机Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IKunpengDesktopCloudHostsService 
{
    /**
     * 查询鲲鹏桌面云主机
     * 
     * @param id 鲲鹏桌面云主机主键
     * @return 鲲鹏桌面云主机
     */
    public KunpengDesktopCloudHosts selectKunpengDesktopCloudHostsById(Integer id);

    /**
     * 查询鲲鹏桌面云主机列表
     * 
     * @param kunpengDesktopCloudHosts 鲲鹏桌面云主机
     * @return 鲲鹏桌面云主机集合
     */
    public List<KunpengDesktopCloudHosts> selectKunpengDesktopCloudHostsList(KunpengDesktopCloudHosts kunpengDesktopCloudHosts);

    /**
     * 新增鲲鹏桌面云主机
     * 
     * @param kunpengDesktopCloudHosts 鲲鹏桌面云主机
     * @return 结果
     */
    public int insertKunpengDesktopCloudHosts(KunpengDesktopCloudHosts kunpengDesktopCloudHosts);

    /**
     * 修改鲲鹏桌面云主机
     * 
     * @param kunpengDesktopCloudHosts 鲲鹏桌面云主机
     * @return 结果
     */
    public int updateKunpengDesktopCloudHosts(KunpengDesktopCloudHosts kunpengDesktopCloudHosts);

    /**
     * 批量删除鲲鹏桌面云主机
     * 
     * @param ids 需要删除的鲲鹏桌面云主机主键集合
     * @return 结果
     */
    public int deleteKunpengDesktopCloudHostsByIds(Integer[] ids);

    /**
     * 删除鲲鹏桌面云主机信息
     * 
     * @param id 鲲鹏桌面云主机主键
     * @return 结果
     */
    public int deleteKunpengDesktopCloudHostsById(Integer id);
}
