package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.KunpengDesktopCloudHosts;
import com.zyc.system.service.IKunpengDesktopCloudHostsService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 鲲鹏桌面云主机Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/KunpengDesktopCloudHostsController")
public class KunpengDesktopCloudHostsController extends BaseController
{
    @Autowired
    private IKunpengDesktopCloudHostsService kunpengDesktopCloudHostsService;

    /**
     * 查询鲲鹏桌面云主机列表
     */
    @PreAuthorize("@ss.hasPermi('system:hosts:list')")
    @GetMapping("/list")
    public TableDataInfo list(KunpengDesktopCloudHosts kunpengDesktopCloudHosts)
    {
        startPage();
        List<KunpengDesktopCloudHosts> list = kunpengDesktopCloudHostsService.selectKunpengDesktopCloudHostsList(kunpengDesktopCloudHosts);
        return getDataTable(list);
    }

    /**
     * 导出鲲鹏桌面云主机列表
     */
    @PreAuthorize("@ss.hasPermi('system:hosts:export')")
    @Log(title = "鲲鹏桌面云主机", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KunpengDesktopCloudHosts kunpengDesktopCloudHosts)
    {
        List<KunpengDesktopCloudHosts> list = kunpengDesktopCloudHostsService.selectKunpengDesktopCloudHostsList(kunpengDesktopCloudHosts);
        ExcelUtil<KunpengDesktopCloudHosts> util = new ExcelUtil<KunpengDesktopCloudHosts>(KunpengDesktopCloudHosts.class);
        util.exportExcel(response, list, "鲲鹏桌面云主机数据");
    }

    /**
     * 获取鲲鹏桌面云主机详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:hosts:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(kunpengDesktopCloudHostsService.selectKunpengDesktopCloudHostsById(id));
    }

    /**
     * 新增鲲鹏桌面云主机
     */
    @PreAuthorize("@ss.hasPermi('system:hosts:add')")
    @Log(title = "鲲鹏桌面云主机", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KunpengDesktopCloudHosts kunpengDesktopCloudHosts)
    {
        return toAjax(kunpengDesktopCloudHostsService.insertKunpengDesktopCloudHosts(kunpengDesktopCloudHosts));
    }

    /**
     * 修改鲲鹏桌面云主机
     */
    @PreAuthorize("@ss.hasPermi('system:hosts:edit')")
    @Log(title = "鲲鹏桌面云主机", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KunpengDesktopCloudHosts kunpengDesktopCloudHosts)
    {
        return toAjax(kunpengDesktopCloudHostsService.updateKunpengDesktopCloudHosts(kunpengDesktopCloudHosts));
    }

    /**
     * 删除鲲鹏桌面云主机
     */
    @PreAuthorize("@ss.hasPermi('system:hosts:remove')")
    @Log(title = "鲲鹏桌面云主机", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(kunpengDesktopCloudHostsService.deleteKunpengDesktopCloudHostsByIds(ids));
    }
}
